pub struct GraphChannelExecutor { /* private fields */ }Expand description
Graph channel executor using a knowledge graph search backend.
Implementations
Sourceimpl GraphChannelExecutor
impl GraphChannelExecutor
Sourcepub fn new(store: Arc<dyn KnowledgeGraphSearch>) -> Self
pub fn new(store: Arc<dyn KnowledgeGraphSearch>) -> Self
Create a new graph channel executor with the given knowledge graph store.
Sourcepub async fn execute(
&self,
query: &str,
config: &ChannelConfig,
_global_filters: &[StructuredFilter],
_namespace: Option<&str>,
) -> Result<Vec<RetrievedChunk>, RagError>
pub async fn execute( &self, query: &str, config: &ChannelConfig, _global_filters: &[StructuredFilter], _namespace: Option<&str>, ) -> Result<Vec<RetrievedChunk>, RagError>
Execute knowledge graph search for the given query.